@@ -1,4 +1,5 @@
 """This package organizes individual libraries employed by glymur."""
-from . import openjp2 as openjp2
 
-__all__ = [openjp2]
+__all__ = ['openjp2']
+
+from . import openjp2 as openjp2
